<?php
/*
 *		Copyright (c) 2002, 2004 C-E-D
 *	              All Rights Reserved
 *
 *	THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF C-E-D
 *	The copyright notice above does not evidence any
 *	actual or intended publication of such source code.
 *	The information in this file is provided "AS IS" without warranty.
 *
 */

/*
 *		module   : TMessage.php
 *		projet   : classe objet message
 *
 *		version  : 2.0
 *		auteur   : laporte
 *		creation : 22/12/04
 *		modif    : 15/07/06 - par D. Laporte
 *                     gnration des fichiers messages (mthode add)
 */


//---------------------------------------------------------------------------
class TMessage
{
	var	$rootDir     = ".";		// rpertoire racine des fichiers messages
	var	$file        = "";		// fichier message
	var	$path        = "";		// fichier mnmonique
	var	$plural      = "s";		// pluriel dans les messages
	var	$isPlural    = false;		// utilisation du pluriel dans les messages
	var	$separator   = "|";		// sparateur mot singulier/pluriel
	var	$raw         = false;		// mode brut d'affichage des messages
	var	$debug       = false;		// mode debug des messages
	var	$varDecl     = array();		// tableau des mnmoniques
	var	$message     = array();		// tableau des messages
	var	$msg_search  = array();		// tableau des chaines de texte  trouver
	var	$msg_replace = array();		// tableau des chaines de texte de remplacement

	// constructeur -------------------------------------------------------
	/*
	 * @author : D. Laporte
	 * @date : Date de cration : 12:40:12 / 3 nov. 04
	 * @date : Date de modification :
	 *
	 * @description : constructeur de la classe TMessage
	 *
	 * @param : string $file
	 * @param : string $rootDir
	 * @return : void
	 *
	 * @access : public
       */
	function TMessage($file, $rootDir = ".")
	{
	/*
	 * fonction :	constructeur
	 * in :		$file, fichier message
	 * 			$rootDir, dossier racine o se trouve les fichiers de messages
	 */

		$this->file    = $file;
		$this->rootDir = $rootDir;

		// le pluriel n'est pas toujours le "s" selon les langues
		if ( strpos($file, "/de/") OR strpos($file, "/it/") )
			$this->plural = "|";

		// lecture des messages
		if ( $this->readMessages() )
			// lecture des mnmoniques
			$this->readHeader();
	}
	// choix du message pour le pluriel -----------------------------------
	function check($msg)
	{
		$words = explode(" ", $msg);

		// recherche de la forme singulier|pluriel
		for ($i = 0; $i < count($words) ; $i++)
			if ( strchr($words[$i], $this->separator) ) {
				$list = explode("|", $words[$i]);

				$msg  = ( $this->isPlural )
					? str_replace($list[0].$this->separator, "", $msg)
					: str_replace($this->separator.$list[1], "", $msg) ;
				}

		return $msg;
	}
	// vrification des messages au pluriel -------------------------------
	function verify($msg)
	{
		if ( $this->plural == "|" )
			return $this->check($msg);

		// s'il y a %s dans la chane, on remplace par la forme plurielle
		return ( $this->isPlural )
			? str_replace("%s", $this->plural, $msg)
			: str_replace("%s", "", $msg) ;
	}
	// lecture du message -------------------------------------------------
	function read_plural($IDmsg, $arg, $bool)
	{
	/*
	 * fonction :	lecture du message
	 * in :		$IDmsg, n du message
	 * 			$arg, n argument dans le message
	 * 			$bool, valeur boolenne pour le pluriel
	 * out :		message texte
	 */

		if ( $IDmsg > -1 AND $IDmsg < $this->count() ) {
			$debug  = ( $this->debug )
				? "#$IDmsg#"
				: "" ;

			$texte  = $debug;
			$texte .= $this->message[$IDmsg];

			if ( $this->raw )
				return $texte;

			if ( !is_array($arg) )
				$texte = str_replace("%1", $arg, $texte);
			else
				for ($i = 1; $i <= sizeof($arg); $i++)
					$texte = str_replace("%$i", $arg[$i-1], $texte);

			$this->isPlural = $bool;

			return $this->verify(str_replace($this->msg_search, $this->msg_replace, $texte));
			}

		// message non trouv
		return "$this->rootDir/$this->file/#$IDmsg#";
	}
	// lecture du message -------------------------------------------------
	function read($IDmsg, $arg = "")
	{
	/*
	 * fonction :	lecture du message
	 * in :		$IDmsg, n du message
	 * 			$arg, n argument dans le message
	 * out :		message texte
	 */

		// message non trouv
		return $this->read_plural($IDmsg, $arg, $this->isPlural); 
	}
	// lecture de l'entte ------------------------------------------------
	function readHeader()
	{
		$list = explode("/", $this->file);

		$this->path = ( count($list) - 2 > 0 ) ? $list[0] : "" ;

		for ($i = 1; $i < count($list) ; $i++)
			if ( $i != count($list) - 2 )
				$this->path .= "/".$list[$i];

		if ( is_file("$this->rootDir/$this->path") )
			if ( ($in  = @fopen("$this->rootDir/$this->path", "r")) ) {

				// raz tableau
				$this->varDecl = array();

				while ( !feof($in) ) {
					$line = fgets($in, 255);
					if ( strstr($line, "static") ) {
						list($i, $j) = preg_split("/[$=]/", $line);
						array_push($this->varDecl, trim($j));
						}
					}

				fclose($in);
				}

		return $this->count();
	}
	// lecture des messages -----------------------------------------------
	function readMessages()
	{
		if ( is_file("$this->rootDir/$this->file") ) {
			// lecture du tableau des messages
			require "$this->rootDir/$this->file";

			$this->message = $message;

			return true;
			}

		return false;
	}
	// cration des liens sur les langues disponibles ---------------------
	function languageBanner($dir, $url="./index.php")
	{
	/*
	 * fonction :	cration de la banire des langues disponibles
	 * in :		$dir, rpertoire des fichiers de langue
	 * 			$url, adresse url de retour
	 * out :		nombre de langues disponibles
	 */

		$href = "";

		// ouverture du rpertoire des langues
		$myDir = @opendir("$this->rootDir/$dir");

		// lecture des rpertoires
		while ( $entry = @readdir($myDir) )
			if ( is_dir("$this->rootDir/$dir/$entry") AND strlen($entry) == 2 )
				switch ( $entry ) {
					case "." :
					case ".." :
						break;

					default :
						$href .= "<a href=\"$url?lang=$entry\"><img src=\"$this->rootDir/images/lang/ico-$entry.png\" title=\"$entry\" alt=\"[$entry]\" /></a>&nbsp;";
						break;
					}

		// fermeture du rpertoire
		@closedir($myDir);

		return $href;
	}
	// cration des liens sur les langues disponibles ---------------------
	function languageList($dir, $url = "")
	{
	/*
	 * fonction :	cration de la banire des langues disponibles
	 * in :		$dir : rpertoire des fichiers de langue, $url : url retour sur formulaire
	 * out :		nombre de langues disponibles
	 */

		$count  = 0;

 		print("<form id=\"langlist\" action=\"$url\" method=\"post\">");
 		print("<select name=\"lang\">");

		// ouverture du rpertoire des langues
		$myDir = @opendir("$this->rootDir/$dir");

		// lecture des rpertoires
		while ( $entry = @readdir($myDir) )
			if ( is_dir("$this->rootDir/$dir/$entry") )
				switch ( $entry ) {
					case "." :
					case ".." :
						break;

					default :
						$count++;
						print("<option value=\"$entry\">$entry</option>");
						break;
					}

		// fermeture du rpertoire
		@closedir($myDir);

 		print("</select>");
 		print("</form>");

		return $count;
	}
	// ajoute/modifie un message ------------------------------------------
	function add($titre, $texte, $IDmsg = -1)
	{
		if ( ($titre = strtoupper(trim($titre))) == "" )
			return 0;

		// ajout de message
		if ( $IDmsg == -1 ) {
			array_push($this->varDecl, $titre);
			array_push($this->message, $texte);
			}
		// modification de message
		else
			if ( $IDmsg < $this->count() ) {
				$this->varDecl[$IDmsg] = $titre;
				$this->message[$IDmsg] = $texte;
				}

		return $this->write();
	}
	// efface un message --------------------------------------------------
	function delete($IDmsg)
	{
		array_splice($this->varDecl, $IDmsg, 1);
		array_splice($this->message, $IDmsg, 1);

		return $this->write();
	}
	// nombre de messages -------------------------------------------------
	function count()
	{
		return ( is_file("$this->rootDir/$this->file") )
			? count($this->varDecl)
			: -1 ;
	}
	// --------------------------------------------------------------------
}
//---------------------------------------------------------------------------
?>