############################################################################
#
# Copyleft (C) 2015 Dominique Laporte <laporte.educnat@gmail.com>
#
# This file is part of smarteo
#
# GNU Lesser General Public License Usage
# Alternatively, this file may be used under the terms of the GNU Lesser
# General Public License version 2.1 or version 3 as published by the Free
# Software Foundation and appearing in the file LICENSE.LGPLv21 and
# LICENSE.LGPLv3 included in the packaging of this file. Please review the
# following information to ensure the GNU Lesser General Public License
# requirements will be met: https://www.gnu.org/licenses/lgpl.html and
# http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
#
############################################################################

# si la base de donnes existe, on la dtruit
drop database if exists `##DATABASE##`;

# et on en cre une nouvelle
create database `##DATABASE##`;

# que l'on utilise
use `##DATABASE##`;

###############################################################################
# table de la configuration smarteo
# ver 1.0
###############################################################################

create table `config` (
	_lang		varchar(2) default 'fr' not null,				# langue utilise
	_maintenance	enum('0', '1') default '0' not null,		# mode maintenance (1 pour activer)
	_timezone	varchar(40) default 'Europe/Paris' not null,	# fuseau horaire
	_charset	varchar(40) default 'iso-8859-1' not null,		# encodage des caractres
	_webmaster	varchar(40) not null,							# email du webmaster
	_timelog	int unsigned default '0' not null,				# dure de stockage des logs : 60 jours (0 si illimit)
	_title		varchar(40) default 'smarteo' not null,		# titre de la fentre
	_keywords	varchar(255) not null,							# description dans le meta
	_maxpage	int unsigned default '50' not null,				# nombre max de donnes par page de prsentation
	_maxshow	int unsigned default '10' not null,				# nombre max de pages accessibles
	primary key (_lang),
	unique key _key(_lang)
	) ENGINE = MyISAM COMMENT = "Table de la configuration smarteo";

###############################################################################
# table de configuration de la base de donnes
# ver 1.0
###############################################################################

create table `config_database` (
	_IDconf	int unsigned not null auto_increment,	# ID de la configuration
	_version	varchar(12) not null,				# version de la bdd
	_IPv6		varchar(24) not null,				# adresse IP v6 du poste sur le LAN
	_date		datetime,							# date et heure de cration/modification de la bdd
	_table		int unsigned not null,				# nombre de tables
	_retcode	int unsigned not null,				# code retour du nombre d'erreurs (0 si ok)
	_lang		varchar(2) not null,				# langue utilise pour la base de donnes
	primary key (_IDconf)
	) ENGINE  = MyISAM COMMENT = "Table de configuration de la base de donnes";

###############################################################################
# table de l'encodage des caractres
# ver 1.0
###############################################################################

create table `config_charset` (
	_IDchar		int unsigned not null auto_increment,	# ID du codage
	_charset	varchar(20) not null,					# nom du codage
	primary key (_IDchar)
	) ENGINE = MyISAM  COMMENT = "Table de l'encodage des caractres";

###############################################################################
# table des fuseaux horaires
# ver 1.0
###############################################################################

create table `config_timezone` (
	_IDzone	int unsigned not null auto_increment,	# ID du fuseau
	_timezone	varchar(40) not null,				# nom du fuseau
	primary key (_IDzone)
	) ENGINE = MyISAM  COMMENT = "Table des fuseaux horaires";
	
###############################################################################
# table des capteurs
# ver 1.0
###############################################################################

create table `capteurs` (
	_ID			int unsigned not null auto_increment,			# ID capteur
	_ident		varchar(5) not null,							# tag du capteur
	_unit		varchar(5),										# unit physique
	primary key (_ID),
	unique key _key(_ident)
	) ENGINE = MyISAM COMMENT = "Table des capteurs";

###############################################################################
# table des capteurs pour l'international
# ver 1.0
###############################################################################

create table `capteurs_i10n` (
	_ID			int unsigned not null,					# ID capteur
	_lang		varchar(2) not null,					# langue de l'utilisateur
	_text		varchar(20),							# description du capteur
	unique key _key(_ID, _lang)
	) ENGINE = MyISAM COMMENT = "Table des capteurs (tiquette)";

###############################################################################
# table des mesures
# ver 1.0
###############################################################################

create table `mesures` (
	_IDmes		int unsigned not null auto_increment,	# ID mesure
	_ID			int unsigned not null,					# ID capteur
	_date		datetime not null,						# date de la mesure
	_value		float,									# valeur mesure
	_text		varchar(5),								# texte mesure (ie : direction vent)
	primary key (_IDmes)
	) ENGINE = MyISAM COMMENT = "Table des mesures";

###############################################################################
# cration de la dba de l'encodage des caractres
###############################################################################
insert into config_charset values('','utf-8');
insert into config_charset values('','utf-16');
insert into config_charset values('','iso-8859-1');
insert into config_charset values('','iso-8859-15');
###############################################################################
insert into config_timezone values('', 'Europe/Amsterdam');
insert into config_timezone values('', 'Europe/Berlin');
insert into config_timezone values('', 'Europe/Chisinau');
insert into config_timezone values('', 'Europe/Helsinki');
insert into config_timezone values('', 'Europe/Kiev');
insert into config_timezone values('', 'Europe/Madrid');
insert into config_timezone values('', 'Europe/Moscow');
insert into config_timezone values('', 'Europe/Prague');
insert into config_timezone values('', 'Europe/Sarajevo');
insert into config_timezone values('', 'Europe/Tallinn');
insert into config_timezone values('', 'Europe/Vatican');
insert into config_timezone values('', 'Europe/Zagreb');
insert into config_timezone values('', 'Europe/Andorra');
insert into config_timezone values('', 'Europe/Bratislava');
insert into config_timezone values('', 'Europe/Copenhagen');
insert into config_timezone values('', 'Europe/Isle_of_Man');
insert into config_timezone values('', 'Europe/Lisbon');
insert into config_timezone values('', 'Europe/Malta');
insert into config_timezone values('', 'Europe/Nicosia');
insert into config_timezone values('', 'Europe/Riga');
insert into config_timezone values('', 'Europe/Simferopol');
insert into config_timezone values('', 'Europe/Tirane');
insert into config_timezone values('', 'Europe/Vienna');
insert into config_timezone values('', 'Europe/Zaporozhye');
insert into config_timezone values('', 'Europe/Athens');
insert into config_timezone values('', 'Europe/Brussels');
insert into config_timezone values('', 'Europe/Dublin');
insert into config_timezone values('', 'Europe/Istanbul');
insert into config_timezone values('', 'Europe/Ljubljana');
insert into config_timezone values('', 'Europe/Mariehamn');
insert into config_timezone values('', 'Europe/Oslo');
insert into config_timezone values('', 'Europe/Rome');
insert into config_timezone values('', 'Europe/Skopje');
insert into config_timezone values('', 'Europe/Tiraspol');
insert into config_timezone values('', 'Europe/Vilnius');
insert into config_timezone values('', 'Europe/Zurich');
insert into config_timezone values('', 'Europe/Belfast');
insert into config_timezone values('', 'Europe/Bucharest');
insert into config_timezone values('', 'Europe/Gibraltar');
insert into config_timezone values('', 'Europe/Jersey');
insert into config_timezone values('', 'Europe/London');
insert into config_timezone values('', 'Europe/Minsk');
insert into config_timezone values('', 'Europe/Paris');
insert into config_timezone values('', 'Europe/Samara');
insert into config_timezone values('', 'Europe/Sofia');
insert into config_timezone values('', 'Europe/Uzhgorod');
insert into config_timezone values('', 'Europe/Volgograd');
insert into config_timezone values('', 'Europe/Belgrade');
insert into config_timezone values('', 'Europe/Budapest');
insert into config_timezone values('', 'Europe/Guernsey');
insert into config_timezone values('', 'Europe/Kaliningrad');
insert into config_timezone values('', 'Europe/Luxembourg');
insert into config_timezone values('', 'Europe/Monaco');
insert into config_timezone values('', 'Europe/Podgorica');
insert into config_timezone values('', 'Europe/San_Marino');
insert into config_timezone values('', 'Europe/Stockholm');
insert into config_timezone values('', 'Europe/Vaduz');
insert into config_timezone values('', 'Europe/Warsaw');
insert into config_timezone values('', 'Africa/Abidjan');
insert into config_timezone values('', 'Africa/Asmera');
insert into config_timezone values('', 'Africa/Blantyre');
insert into config_timezone values('', 'Africa/Ceuta');
insert into config_timezone values('', 'Africa/Douala');
insert into config_timezone values('', 'Africa/Johannesburg');
insert into config_timezone values('', 'Africa/Lagos');
insert into config_timezone values('', 'Africa/Lusaka');
insert into config_timezone values('', 'Africa/Mogadishu');
insert into config_timezone values('', 'Africa/Nouakchott');
insert into config_timezone values('', 'Africa/Tripoli');
insert into config_timezone values('', 'Africa/Accra');
insert into config_timezone values('', 'Africa/Bamako');
insert into config_timezone values('', 'Africa/Brazzaville');
insert into config_timezone values('', 'Africa/Conakry');
insert into config_timezone values('', 'Africa/El_Aaiun');
insert into config_timezone values('', 'Africa/Kampala');
insert into config_timezone values('', 'Africa/Libreville');
insert into config_timezone values('', 'Africa/Malabo');
insert into config_timezone values('', 'Africa/Monrovia');
insert into config_timezone values('', 'Africa/Ouagadougou');
insert into config_timezone values('', 'Africa/Tunis');
insert into config_timezone values('', 'Africa/Addis_Ababa');
insert into config_timezone values('', 'Africa/Bangui');
insert into config_timezone values('', 'Africa/Bujumbura');
insert into config_timezone values('', 'Africa/Dakar');
insert into config_timezone values('', 'Africa/Freetown');
insert into config_timezone values('', 'Africa/Khartoum');
insert into config_timezone values('', 'Africa/Lome');
insert into config_timezone values('', 'Africa/Maputo');
insert into config_timezone values('', 'Africa/Nairobi');
insert into config_timezone values('', 'Africa/Porto-Novo');
insert into config_timezone values('', 'Africa/Windhoek');
insert into config_timezone values('', 'Africa/Algiers');
insert into config_timezone values('', 'Africa/Banjul');
insert into config_timezone values('', 'Africa/Cairo');
insert into config_timezone values('', 'Africa/Dar_es_Salaam');
insert into config_timezone values('', 'Africa/Gaborone');
insert into config_timezone values('', 'Africa/Kigali');
insert into config_timezone values('', 'Africa/Luanda');
insert into config_timezone values('', 'Africa/Maseru');
insert into config_timezone values('', 'Africa/Ndjamena');
insert into config_timezone values('', 'Africa/Sao_Tome');
insert into config_timezone values('', 'Africa/Asmara');
insert into config_timezone values('', 'Africa/Bissau');
insert into config_timezone values('', 'Africa/Casablanca');
insert into config_timezone values('', 'Africa/Djibouti');
insert into config_timezone values('', 'Africa/Harare');
insert into config_timezone values('', 'Africa/Kinshasa');
insert into config_timezone values('', 'Africa/Lubumbashi');
insert into config_timezone values('', 'Africa/Mbabane');
insert into config_timezone values('', 'Africa/Niamey');
insert into config_timezone values('', 'Africa/Timbuktu');
insert into config_timezone values('', 'America/Adak');
insert into config_timezone values('', 'America/Argentina/Buenos_Aires');
insert into config_timezone values('', 'America/Argentina/La_Rioja');
insert into config_timezone values('', 'America/Argentina/San_Luis');
insert into config_timezone values('', 'America/Atikokan');
insert into config_timezone values('', 'America/Belem');
insert into config_timezone values('', 'America/Boise');
insert into config_timezone values('', 'America/Caracas');
insert into config_timezone values('', 'America/Chihuahua');
insert into config_timezone values('', 'America/Curacao');
insert into config_timezone values('', 'America/Detroit');
insert into config_timezone values('', 'America/Ensenada');
insert into config_timezone values('', 'America/Goose_Bay');
insert into config_timezone values('', 'America/Guayaquil');
insert into config_timezone values('', 'America/Indiana/Indianapolis');
insert into config_timezone values('', 'America/Indiana/Vevay');
insert into config_timezone values('', 'America/Iqaluit');
insert into config_timezone values('', 'America/Kentucky/Monticello');
insert into config_timezone values('', 'America/Louisville');
insert into config_timezone values('', 'America/Martinique');
insert into config_timezone values('', 'America/Merida');
insert into config_timezone values('', 'America/Montevideo');
insert into config_timezone values('', 'America/Nipigon');
insert into config_timezone values('', 'America/North_Dakota/New_Salem');
insert into config_timezone values('', 'America/Phoenix');
insert into config_timezone values('', 'America/Puerto_Rico');
insert into config_timezone values('', 'America/Resolute');
insert into config_timezone values('', 'America/Santiago');
insert into config_timezone values('', 'America/St_Barthelemy');
insert into config_timezone values('', 'America/St_Vincent');
insert into config_timezone values('', 'America/Tijuana');
insert into config_timezone values('', 'America/Whitehorse');
insert into config_timezone values('', 'America/Anchorage');
insert into config_timezone values('', 'America/Argentina/Catamarca');
insert into config_timezone values('', 'America/Argentina/Mendoza');
insert into config_timezone values('', 'America/Argentina/Tucuman');
insert into config_timezone values('', 'America/Atka');
insert into config_timezone values('', 'America/Belize');
insert into config_timezone values('', 'America/Buenos_Aires');
insert into config_timezone values('', 'America/Catamarca');
insert into config_timezone values('', 'America/Coral_Harbour');
insert into config_timezone values('', 'America/Danmarkshavn');
insert into config_timezone values('', 'America/Dominica');
insert into config_timezone values('', 'America/Fort_Wayne');
insert into config_timezone values('', 'America/Grand_Turk');
insert into config_timezone values('', 'America/Guyana');
insert into config_timezone values('', 'America/Indiana/Knox');
insert into config_timezone values('', 'America/Indiana/Vincennes');
insert into config_timezone values('', 'America/Jamaica');
insert into config_timezone values('', 'America/Knox_IN');
insert into config_timezone values('', 'America/Maceio');
insert into config_timezone values('', 'America/Matamoros');
insert into config_timezone values('', 'America/Mexico_City');
insert into config_timezone values('', 'America/Montreal');
insert into config_timezone values('', 'America/Nome');
insert into config_timezone values('', 'America/Ojinaga');
insert into config_timezone values('', 'America/Port-au-Prince');
insert into config_timezone values('', 'America/Rainy_River');
insert into config_timezone values('', 'America/Rio_Branco');
insert into config_timezone values('', 'America/Santo_Domingo');
insert into config_timezone values('', 'America/St_Johns');
insert into config_timezone values('', 'America/Swift_Current');
insert into config_timezone values('', 'America/Toronto');
insert into config_timezone values('', 'America/Winnipeg');
insert into config_timezone values('', 'America/Anguilla');
insert into config_timezone values('', 'America/Argentina/ComodRivadavia');
insert into config_timezone values('', 'America/Argentina/Rio_Gallegos');
insert into config_timezone values('', 'America/Argentina/Ushuaia');
insert into config_timezone values('', 'America/Bahia');
insert into config_timezone values('', 'America/Blanc-Sablon');
insert into config_timezone values('', 'America/Cambridge_Bay');
insert into config_timezone values('', 'America/Cayenne');
insert into config_timezone values('', 'America/Cordoba');
insert into config_timezone values('', 'America/Dawson');
insert into config_timezone values('', 'America/Edmonton');
insert into config_timezone values('', 'America/Fortaleza');
insert into config_timezone values('', 'America/Grenada');
insert into config_timezone values('', 'America/Halifax');
insert into config_timezone values('', 'America/Indiana/Marengo');
insert into config_timezone values('', 'America/Indiana/Winamac');
insert into config_timezone values('', 'America/Jujuy');
insert into config_timezone values('', 'America/La_Paz');
insert into config_timezone values('', 'America/Managua');
insert into config_timezone values('', 'America/Mazatlan');
insert into config_timezone values('', 'America/Miquelon');
insert into config_timezone values('', 'America/Montserrat');
insert into config_timezone values('', 'America/Noronha');
insert into config_timezone values('', 'America/Panama');
insert into config_timezone values('', 'America/Port_of_Spain');
insert into config_timezone values('', 'America/Rankin_Inlet');
insert into config_timezone values('', 'America/Rosario');
insert into config_timezone values('', 'America/Sao_Paulo');
insert into config_timezone values('', 'America/St_Kitts');
insert into config_timezone values('', 'America/Tegucigalpa');
insert into config_timezone values('', 'America/Tortola');
insert into config_timezone values('', 'America/Yakutat');
insert into config_timezone values('', 'America/Antigua');
insert into config_timezone values('', 'America/Argentina/Cordoba');
insert into config_timezone values('', 'America/Argentina/Salta');
insert into config_timezone values('', 'America/Aruba');
insert into config_timezone values('', 'America/Bahia_Banderas');
insert into config_timezone values('', 'America/Boa_Vista');
insert into config_timezone values('', 'America/Campo_Grande');
insert into config_timezone values('', 'America/Cayman');
insert into config_timezone values('', 'America/Costa_Rica');
insert into config_timezone values('', 'America/Dawson_Creek');
insert into config_timezone values('', 'America/Eirunepe');
insert into config_timezone values('', 'America/Glace_Bay');
insert into config_timezone values('', 'America/Guadeloupe');
insert into config_timezone values('', 'America/Havana');
insert into config_timezone values('', 'America/Indiana/Petersburg');
insert into config_timezone values('', 'America/Indianapolis');
insert into config_timezone values('', 'America/Juneau');
insert into config_timezone values('', 'America/Lima');
insert into config_timezone values('', 'America/Manaus');
insert into config_timezone values('', 'America/Mendoza');
insert into config_timezone values('', 'America/Moncton');
insert into config_timezone values('', 'America/Nassau');
insert into config_timezone values('', 'America/North_Dakota/Beulah');
insert into config_timezone values('', 'America/Pangnirtung');
insert into config_timezone values('', 'America/Porto_Acre');
insert into config_timezone values('', 'America/Recife');
insert into config_timezone values('', 'America/Santa_Isabel');
insert into config_timezone values('', 'America/Scoresbysund');
insert into config_timezone values('', 'America/St_Lucia');
insert into config_timezone values('', 'America/Thule');
insert into config_timezone values('', 'America/Vancouver');
insert into config_timezone values('', 'America/Yellowknife');
insert into config_timezone values('', 'America/Araguaina');
insert into config_timezone values('', 'America/Argentina/Jujuy');
insert into config_timezone values('', 'America/Argentina/San_Juan');
insert into config_timezone values('', 'America/Asuncion');
insert into config_timezone values('', 'America/Barbados');
insert into config_timezone values('', 'America/Bogota');
insert into config_timezone values('', 'America/Cancun');
insert into config_timezone values('', 'America/Chicago');
insert into config_timezone values('', 'America/Cuiaba');
insert into config_timezone values('', 'America/Denver');
insert into config_timezone values('', 'America/El_Salvador');
insert into config_timezone values('', 'America/Godthab');
insert into config_timezone values('', 'America/Guatemala');
insert into config_timezone values('', 'America/Hermosillo');
insert into config_timezone values('', 'America/Indiana/Tell_City');
insert into config_timezone values('', 'America/Inuvik');
insert into config_timezone values('', 'America/Kentucky/Louisville');
insert into config_timezone values('', 'America/Los_Angeles');
insert into config_timezone values('', 'America/Marigot');
insert into config_timezone values('', 'America/Menominee');
insert into config_timezone values('', 'America/Monterrey');
insert into config_timezone values('', 'America/New_York');
insert into config_timezone values('', 'America/North_Dakota/Center');
insert into config_timezone values('', 'America/Paramaribo');
insert into config_timezone values('', 'America/Porto_Velho');
insert into config_timezone values('', 'America/Regina');
insert into config_timezone values('', 'America/Santarem');
insert into config_timezone values('', 'America/Shiprock');
insert into config_timezone values('', 'America/St_Thomas');
insert into config_timezone values('', 'America/Thunder_Bay');
insert into config_timezone values('', 'America/Virgin');
insert into config_timezone values('', 'Asia/Aden');
insert into config_timezone values('', 'Asia/Aqtobe');
insert into config_timezone values('', 'Asia/Baku');
insert into config_timezone values('', 'Asia/Calcutta');
insert into config_timezone values('', 'Asia/Dacca');
insert into config_timezone values('', 'Asia/Dushanbe');
insert into config_timezone values('', 'Asia/Hovd');
insert into config_timezone values('', 'Asia/Jerusalem');
insert into config_timezone values('', 'Asia/Kathmandu');
insert into config_timezone values('', 'Asia/Kuching');
insert into config_timezone values('', 'Asia/Makassar');
insert into config_timezone values('', 'Asia/Novosibirsk');
insert into config_timezone values('', 'Asia/Pyongyang');
insert into config_timezone values('', 'Asia/Saigon');
insert into config_timezone values('', 'Asia/Singapore');
insert into config_timezone values('', 'Asia/Tel_Aviv');
insert into config_timezone values('', 'Asia/Ulaanbaatar');
insert into config_timezone values('', 'Asia/Yakutsk');
insert into config_timezone values('', 'Asia/Almaty');
insert into config_timezone values('', 'Asia/Ashgabat');
insert into config_timezone values('', 'Asia/Bangkok');
insert into config_timezone values('', 'Asia/Choibalsan');
insert into config_timezone values('', 'Asia/Damascus');
insert into config_timezone values('', 'Asia/Gaza');
insert into config_timezone values('', 'Asia/Irkutsk');
insert into config_timezone values('', 'Asia/Kabul');
insert into config_timezone values('', 'Asia/Katmandu');
insert into config_timezone values('', 'Asia/Kuwait');
insert into config_timezone values('', 'Asia/Manila');
insert into config_timezone values('', 'Asia/Omsk');
insert into config_timezone values('', 'Asia/Qatar');
insert into config_timezone values('', 'Asia/Sakhalin');
insert into config_timezone values('', 'Asia/Taipei');
insert into config_timezone values('', 'Asia/Thimbu');
insert into config_timezone values('', 'Asia/Ulan_Bator');
insert into config_timezone values('', 'Asia/Yekaterinburg');
insert into config_timezone values('', 'Asia/Amman');
insert into config_timezone values('', 'Asia/Ashkhabad');
insert into config_timezone values('', 'Asia/Beirut');
insert into config_timezone values('', 'Asia/Chongqing');
insert into config_timezone values('', 'Asia/Dhaka');
insert into config_timezone values('', 'Asia/Harbin');
insert into config_timezone values('', 'Asia/Istanbul');
insert into config_timezone values('', 'Asia/Kamchatka');
insert into config_timezone values('', 'Asia/Kolkata');
insert into config_timezone values('', 'Asia/Macao');
insert into config_timezone values('', 'Asia/Muscat');
insert into config_timezone values('', 'Asia/Oral');
insert into config_timezone values('', 'Asia/Qyzylorda');
insert into config_timezone values('', 'Asia/Samarkand');
insert into config_timezone values('', 'Asia/Tashkent');
insert into config_timezone values('', 'Asia/Thimphu');
insert into config_timezone values('', 'Asia/Urumqi');
insert into config_timezone values('', 'Asia/Yerevan');
insert into config_timezone values('', 'Asia/Anadyr');
insert into config_timezone values('', 'Asia/Baghdad');
insert into config_timezone values('', 'Asia/Bishkek');
insert into config_timezone values('', 'Asia/Chungking');
insert into config_timezone values('', 'Asia/Dili');
insert into config_timezone values('', 'Asia/Ho_Chi_Minh');
insert into config_timezone values('', 'Asia/Jakarta');
insert into config_timezone values('', 'Asia/Karachi');
insert into config_timezone values('', 'Asia/Krasnoyarsk');
insert into config_timezone values('', 'Asia/Macau');
insert into config_timezone values('', 'Asia/Nicosia');
insert into config_timezone values('', 'Asia/Phnom_Penh');
insert into config_timezone values('', 'Asia/Rangoon');
insert into config_timezone values('', 'Asia/Seoul');
insert into config_timezone values('', 'Asia/Tbilisi');
insert into config_timezone values('', 'Asia/Tokyo');
insert into config_timezone values('', 'Asia/Vientiane');
insert into config_timezone values('', 'Asia/Aqtau');
insert into config_timezone values('', 'Asia/Bahrain');
insert into config_timezone values('', 'Asia/Brunei');
insert into config_timezone values('', 'Asia/Colombo');
insert into config_timezone values('', 'Asia/Dubai');
insert into config_timezone values('', 'Asia/Hong_Kong');
insert into config_timezone values('', 'Asia/Jayapura');
insert into config_timezone values('', 'Asia/Kashgar');
insert into config_timezone values('', 'Asia/Kuala_Lumpur');
insert into config_timezone values('', 'Asia/Magadan');
insert into config_timezone values('', 'Asia/Novokuznetsk');
insert into config_timezone values('', 'Asia/Pontianak');
insert into config_timezone values('', 'Asia/Riyadh');
insert into config_timezone values('', 'Asia/Shanghai');
insert into config_timezone values('', 'Asia/Tehran');
insert into config_timezone values('', 'Asia/Ujung_Pandang');
insert into config_timezone values('', 'Asia/Vladivostok');
insert into config_timezone values('', 'Atlantic/Azores');
insert into config_timezone values('', 'Atlantic/Faroe');
insert into config_timezone values('', 'Atlantic/St_Helena');
insert into config_timezone values('', 'Atlantic/Bermuda');
insert into config_timezone values('', 'Atlantic/Jan_Mayen');
insert into config_timezone values('', 'Atlantic/Stanley');
insert into config_timezone values('', 'Atlantic/Canary');
insert into config_timezone values('', 'Atlantic/Madeira');
insert into config_timezone values('', 'Atlantic/Cape_Verde');
insert into config_timezone values('', 'Atlantic/Reykjavik');
insert into config_timezone values('', 'Atlantic/Faeroe');
insert into config_timezone values('', 'Atlantic/South_Georgia');
insert into config_timezone values('', 'Australia/ACT');
insert into config_timezone values('', 'Australia/Currie');
insert into config_timezone values('', 'Australia/Lindeman');
insert into config_timezone values('', 'Australia/Perth');
insert into config_timezone values('', 'Australia/Victoria');
insert into config_timezone values('', 'Australia/Adelaide');
insert into config_timezone values('', 'Australia/Darwin');
insert into config_timezone values('', 'Australia/Lord_Howe');
insert into config_timezone values('', 'Australia/Queensland');
insert into config_timezone values('', 'Australia/West');
insert into config_timezone values('', 'Australia/Brisbane');
insert into config_timezone values('', 'Australia/Eucla');
insert into config_timezone values('', 'Australia/Melbourne');
insert into config_timezone values('', 'Australia/South');
insert into config_timezone values('', 'Australia/Yancowinna');
insert into config_timezone values('', 'Australia/Broken_Hill');
insert into config_timezone values('', 'Australia/Hobart');
insert into config_timezone values('', 'Australia/North');
insert into config_timezone values('', 'Australia/Sydney');
insert into config_timezone values('', 'Australia/Canberra');
insert into config_timezone values('', 'Australia/LHI');
insert into config_timezone values('', 'Australia/NSW');
insert into config_timezone values('', 'Australia/Tasmania');
insert into config_timezone values('', 'Indian/Antananarivo');
insert into config_timezone values('', 'Indian/Kerguelen');
insert into config_timezone values('', 'Indian/Reunion');
insert into config_timezone values('', 'Indian/Chagos');
insert into config_timezone values('', 'Indian/Mahe');
insert into config_timezone values('', 'Indian/Christmas');
insert into config_timezone values('', 'Indian/Maldives');
insert into config_timezone values('', 'Indian/Cocos');
insert into config_timezone values('', 'Indian/Mauritius');
insert into config_timezone values('', 'Indian/Comoro');
insert into config_timezone values('', 'Indian/Mayotte');
insert into config_timezone values('', 'Pacific/Apia');
insert into config_timezone values('', 'Pacific/Efate');
insert into config_timezone values('', 'Pacific/Galapagos');
insert into config_timezone values('', 'Pacific/Johnston');
insert into config_timezone values('', 'Pacific/Marquesas');
insert into config_timezone values('', 'Pacific/Noumea');
insert into config_timezone values('', 'Pacific/Ponape');
insert into config_timezone values('', 'Pacific/Tahiti');
insert into config_timezone values('', 'Pacific/Wallis');
insert into config_timezone values('', 'Pacific/Auckland');
insert into config_timezone values('', 'Pacific/Enderbury');
insert into config_timezone values('', 'Pacific/Gambier');
insert into config_timezone values('', 'Pacific/Kiritimati');
insert into config_timezone values('', 'Pacific/Midway');
insert into config_timezone values('', 'Pacific/Pago_Pago');
insert into config_timezone values('', 'Pacific/Port_Moresby');
insert into config_timezone values('', 'Pacific/Tarawa');
insert into config_timezone values('', 'Pacific/Yap');
insert into config_timezone values('', 'Pacific/Chatham');
###############################################################################