<?php
/****************************************************************************
**
** Copyleft (C) 2015 Dominique Laporte <laporte.educnat@gmail.com>
**
** This file is part of smarteo
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file. Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
****************************************************************************/

/*
 *		module   : setup.php
 *		projet   : la page de configuration automatique de la base de donnes
 *
 *		version  : 1.0
 *		auteur   : laporte
 *		creation : 30/08/10
 *		modif    : 
 */



// --------------------------------------------------------------------
function stripComment($string)
{
/*
 * fonction :	enlve les commentaires d'une requte SQL
 * in :		$string, requte SQL  traiter
 * out :		requte SQL sans commentaire
 */

	if ( $string == "" )
		return "";

	$ret = strpos($string, "#");
	$pos = ( $ret == false AND $string[0] != '#' ) ? -1 : $ret ;
	$p   = $pos - 1;

	if ( $pos > -1 ) {
		if ( $p > 0 ) {
			while ( $pos > -1 AND $string[$p] != "\t" ) {
				$ret = strpos(substr($string, $pos + 1, strlen($string)), "#");
				if ( $ret == false )
					$pos = -1;
				else
					$pos += strpos(substr($string, $pos + 1, strlen($string)), "#") + 1;
				$p   = $pos - 1;
				}

			return ( $p > 0 AND @$string[$p] == "\t" )
				? substr($string, 0, $p)
				: $string ;
			}
		else
			return "";
		}
	else
		return $string;
}
// --------------------------------------------------------------------
function request($database, $file, &$sqlerror)
{
/*
 * fonction :	excution de requte SQL
 * in :		$database, nom de la base de donnes
 *			$file, nom de fichier MySQL
 * out :		-1 si fichier SQL introuvable, nombre d'erreur de syntaxe SQL sinon
 */

	// ouverture fichiers
	if ( !($in  = @fopen($file, "r")) )
		return -1;

	// initialisation requte
	$query  = "";
	$erreur = 0;

	// lecture fichier sql
	$count = 1;

	while ( !feof($in) ) {
		// suppression des blancs et retour charriots
		$line = trim(str_replace("\n", "", fgets($in, 2048)));
		$line = str_replace("##DATABASE##", $database, $line);

		// suppression des commentaires
		$line = stripComment($line);

		// construction de la requte
		if ( strlen($line) ) {
			$query .= $line;

			// validation de la requte
			if ( strrpos($line, ";") == strlen($line) - 1 ) {
				// lancement de la requte
				if ( !$_SESSION["mysqli"]->query($query) ) {
					$sqlerror .= "<span style=\"color:#FF0000; font-weight: bold;\">Error ".$_SESSION["mysqli"]->errno."</span> : ($file @ $count) ".$_SESSION["mysqli"]->error.".<br/>";
					$erreur++;
					}

				$query = "";
				}
			}

		$count++;
		}

	//fermeture fichiers
	fclose($in);

	return $erreur;
}
// --------------------------------------------------------------------
function updatedatabase($databese, $langlist, &$sqlerror)
{
	global $VERSION;

	require "./msg/setup.php";

	require_once $_SESSION["ROOTDIR"]."/include/TMessage.php";

	$msg  = new TMessage("./msg/".$_SESSION["lang"]."/setup.php");

	// initialisation
	$error    = 0;

	// on met  jour la bdd
	list($major, $minor) = preg_split("/[.rc]/", $VERSION);

	$M = (int) $major;
	$m = (int) $minor;

	// l'incrmentation automatique
	$query  = "select _version, _retcode ";
	$query .= "from $database.config_database ";
	$query .= "order by _IDconf desc ";
	$query .= "limit 1";

	$result = $_SESSION["mysqli"]->query($query);
	$row    = ( $result ) ? $result->fetch_row($result) : 0 ;

	// attention  une table vide
	if ( $_SESSION["mysqli"]->affected_rows() ) {
		list($M, $m) = preg_split("/[.rc]/", $row[0]);

		// si l'installation de la dernire maj est correcte
		// on passe  la version suivante
		// sauf si mode forage
		if ( (int) $row[1] == 0 OR $force )
			$m++;
		}

	// on effectue les mises  jour incrmentales
	for ($i = $M; $i <= $major && $error == 0; $i++) {
		for ($j = $m; $j <= $minor && $error == 0; $j++) {
			// pour l'instant on ne gre pas les versions correctives
			$version = "$i.$j"."rc1";

			if ( file_exists("./mysql/update/database-$version.sql") ) {
				$error += request($database, "./mysql/update/database-$version.sql", $slqerror);

				// lecture des rpertoires de langues
				for ($k = 0; $k < count($langlist); $k++) {
					$path = "./mysql/update/".$langlist[$k]."/database-$version.sql";

					if ( file_exists($path) )
						$error += request($database, $path, $slqerror);
					}

				// tables dans la base de donnes
				$result = $_SESSION["mysqli"]->query("show tables from $database");
				$tables = ( $result ) ? $result->numrows : 0 ;

				// log des mises  jour
				$_SESSION["mysqli"]->query("insert into config_database values('', '$version', '". @$_SERVER["REMOTE_ADDR"] ."', '".date("Y-m-d H:i:s")."', '$tables', '$error', '". $_SESSION["lang"] ."')");

				$img = ( $error ) ? "off" : "on" ;
				$alt = ( $error ) ? "X" : "O" ;

				$sqlerror .= "<br/>". $msg->read($MSG_UPDATE, $version) ." ";
				$sqlerror .= "<img src=\"./images/check_$img.png\" title=\"\" alt=\"$alt\" />";
				}

			// application des patch
			if ( file_exists("./mysql/update/patch/patch-$version.php") ) {
				require "./mysql/update/patch/patch-$version.php";

				if ( function_exists('patch') )
					patch();

				$img = ( !function_exists('patch') ) ? "off" : "on" ;
				$alt = ( $error ) ? "X" : "O" ;

				$sqlerror .= "<br/>". $msg->read($MSG_PATCH, "patch-$version.php") ." ";
				$sqlerror .= "<img src=\"./images/check_$img.png\" title=\"\" alt=\"$alt\" />";
				}
			}	// endfor minor

		$m = 0; $minor = 12;
		}	// endfor major

	return $error;
}
// --------------------------------------------------------------------
function createdatabase($database, $langlist, $dba, &$sqlerror)
{
	global $VERSION;

	// la cration de la DB peut prendre du temps => on supprime le tps max d'excution des requtes
	// attention : safe_mode doit tre dsactiv
	$safe_mode  = ini_get("safe_mode");
	$time_limit = ini_get("max_execution_time");

	if ( $safe_mode != "1" )
		set_time_limit(0);

	// choix de la base de donnes
	$path = ( $dba )
		? "./mysql/$dba"
		: "./mysql" ;

	if ( ($error = request($database, "$path/database.sql", $sqlerror)) == -1 )
		return -2;

	// ouverture du rpertoire des fichiers sql
	$myDir = @opendir($path);

	// lecture des fichiers sql
	while ( $entry = @readdir($myDir) )
		if ( strstr($entry, ".sql") )
			if ( $entry != "database.sql" )
				$error += request($database, "$path/$entry", $sqlerror);

	// fermeture du rpertoire
	@closedir($myDir);

	// lecture des rpertoires sql/langues
	for ($k = 0; $k < count($langlist); $k++) {
		$myDir = @opendir("$path/".$langlist[$k]);

		// lecture des fichiers sql
		while ( $entry = @readdir($myDir) )
			if ( strstr($entry, ".sql") )
				$error += request($database, "$path/".$langlist[$k]."/$entry", $sqlerror);

		// fermeture du rpertoire
		@closedir($myDir);
		}

	// tables dans la base de donnes
	$result = $_SESSION["mysqli"]->query("show tables from $database");
	$tables = ( $result ) ? $result->num_rows : 0 ;

	// log des crations
	$query  = "insert into config_database ";
	$query .= "values('', '$VERSION', '". @$_SERVER["REMOTE_ADDR"] ."', '".date("Y-m-d H:i:s")."', '$tables', '$error', '". $_SESSION["lang"] ."')";

	$_SESSION["mysqli"]->query($query);

	// rinitialisation du tps max d'excution des requtes
	if ( $safe_mode != "1" )
		set_time_limit($time_limit);

	return $error;
}
// --------------------------------------------------------------------
function writeconfigfile($input, $output,
	$server, $user, $passwd, $database, $servport, $charset)
{
	// ouverture des fichiers
	if ( !file_exists($input) )
		return -1;

	if ( !($out = @fopen($output, "w")) )
		return -2;

	// modification fichier de configuration
	fputs($out, 
		str_replace(
			Array(
				"##SERVER##",
				"##USER##",
				"##PASSWD##",
				"##DATABASE##",
				"##SERVPORT##",
				"##CHARSET##"
				),
			Array(
				str_replace(Array('$', '"'), Array('\$', '\"'), $server),
				str_replace(Array('$', '"'), Array('\$', '\"'), $user),
				str_replace(Array('$', '"'), Array('\$', '\"'), $passwd),
				str_replace(Array('$', '"'), Array('\$', '\"'), $database),
				strval($servport),
				str_replace(Array('$', '"'), Array('\$', '\"'), $charset)
				),
			file_get_contents($input))
		);

	//fermeture fichiers
	fclose($out);

	return 0;
}
//---------------------------------------------------------------------------
?>